@@ -6,7 +6,7 @@ use Carp;
 use Class::Load qw/ try_load_class /;
 use PerlX::Maybe;
 
-use version 0.77; our $VERSION = version->declare('v0.1.1');
+use version 0.77; our $VERSION = version->declare('v0.1.2');
 
 # RECOMMEND PREREQ: Class::Load::XS
 # RECOMMEND PREREQ: PerlX::Maybe::XS
@@ -15,6 +15,8 @@ use version 0.77; our $VERSION = version->declare('v0.1.1');
 
 MooseX::Failover - Instantiate Moose classes with failover
 
+=for readme plugin version
+
 =head1 SYNOPSIS
 
   # In your class:
@@ -31,6 +33,19 @@ MooseX::Failover - Instantiate Moose classes with failover
   # If %args contains missing or invalid values or new otherwise
   # fails, then $obj will be of type "OtherClass".
 
+=begin :readme
+
+=head1 INSTALLATION
+
+See
+L<How to install CPAN modules|http://www.cpan.org/modules/INSTALL.html>.
+
+=for readme plugin requires heading-level=2 title="Required Modules"
+
+=for readme plugin changes
+
+=end :readme
+
 =head1 DESCRIPTION
 
 This role provides constructor failover for L<Moose> classes.
@@ -58,6 +73,8 @@ class are also provable of the failover class.  In practice, we only
 care about the properties (methods and attributes) that are actually
 used in our programs.
 
+=for readme stop
+
 =head1 ARGUMENTS
 
 =head2 C<failover_to>
@@ -165,6 +182,8 @@ around new => sub {
 
 };
 
+=for readme continue
+
 =head1 AUTHOR
 
 Robert Rothenberg C<<rrwo@thermeon.com>>
